@@ -22,6 +22,7 @@
 import pickle
 import os
 
+import rolenames
 import speech
 import settings
 import orca_state
@@ -122,10 +123,11 @@ class Bookmarks:
         p = cur_obj.parent
         while p:
             if bookmark_ancestors.count(p) > 0:
+                rolename = rolenames.getSpeechForRoleName(p)
                 # Translators: this announces that the bookmark and the current
                 # object share a common ancestor
                 #
-                self._script.presentMessage(_('shared ancestor %s') % p.role)
+                self._script.presentMessage(_('shared ancestor %s') % rolename)
                 return
             p = p.parent
 
